@@ -30,7 +30,7 @@ extern void F77_NAME(linkinv)(void *, void *, void *, void *);
 extern void F77_NAME(lmax_zipath)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void*);
 extern void F77_NAME(loglikfor)(void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(loss)(void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(nclreg_ad)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(nclreg_ad)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(nclreg_fortran)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(nonconvexloss)(void *, void *, void *, void *);
 extern void F77_NAME(outloop)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
@@ -41,9 +41,9 @@ extern void F77_NAME(pred)(void *, void *, void *, void *, void *, void *, void
 extern void F77_NAME(theta_ml)(void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(zeval)(void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(ziloss)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(zi_onelambda)(void *, void *, void *, void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(zipath_active)(void *, void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
-extern void F77_NAME(zipath_nonactive)(void *, void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(zi_onelambda)(void *, void *, void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(zipath_active)(void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(zipath_nonactive)(void *, void *, void*, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_FortranMethodDef FortranEntries[] = {
 	    {"checkconvergence",           (DL_FUNC) &F77_NAME(checkconvergence),    8},
@@ -60,7 +60,7 @@ static const R_FortranMethodDef FortranEntries[] = {
 	    {"lmax_zipath",                (DL_FUNC) &F77_NAME(lmax_zipath),        18},
 	    {"loglikfor",                  (DL_FUNC) &F77_NAME(loglikfor),           7},
 	    {"loss",                       (DL_FUNC) &F77_NAME(loss),                7},
-	    {"nclreg_ad",                  (DL_FUNC) &F77_NAME(nclreg_ad),          35},
+	    {"nclreg_ad",                  (DL_FUNC) &F77_NAME(nclreg_ad),          34},
 	    {"nclreg_fortran",             (DL_FUNC) &F77_NAME(nclreg_fortran),     35},
 	    {"nonconvesloss",              (DL_FUNC) &F77_NAME(nonconvexloss),       4},
 	    {"outloop",                    (DL_FUNC) &F77_NAME(outloop),            35},
@@ -71,9 +71,9 @@ static const R_FortranMethodDef FortranEntries[] = {
 	    {"theta_ml",                   (DL_FUNC) &F77_NAME(theta_ml),            8},
 	    {"zeval",                      (DL_FUNC) &F77_NAME(zeval),               7},
 	    {"ziloss",                     (DL_FUNC) &F77_NAME(ziloss),             10},
-	    {"zi_onelambda",               (DL_FUNC) &F77_NAME(zi_onelambda),       43},
-	    {"zipath_active",              (DL_FUNC) &F77_NAME(zipath_active),      41},
-	    {"zipath_nonactive",           (DL_FUNC) &F77_NAME(zipath_nonactive),   41},
+	    {"zi_onelambda",               (DL_FUNC) &F77_NAME(zi_onelambda),       42},
+	    {"zipath_active",              (DL_FUNC) &F77_NAME(zipath_active),      40},
+	    {"zipath_nonactive",           (DL_FUNC) &F77_NAME(zipath_nonactive),   40},
 					        {NULL, NULL, 0}
 };
 
